@@ -14,15 +14,15 @@ from deprecated.sphinx import versionchanged
     
     Just guess!
     """,
-    version='0.3.0')
+    version='0.3.0',
+)
 @versionchanged(
     reason='Well, I add a new feature in this function. '
-           'It is very useful as you can see in the example below, so try it. '
-           'This is a very very very very very long sentence.',
-    version='0.2.0')
-@versionadded(
-    reason='Here is my new function.',
-    version='0.1.0')
+    'It is very useful as you can see in the example below, so try it. '
+    'This is a very very very very very long sentence.',
+    version='0.2.0',
+)
+@versionadded(reason='Here is my new function.', version='0.1.0')
 def successor(n):
     """
     Calculate the successor of a number.
